import argparse
from titere import Titere
from termcolor import colored


def main():
    """
    Main command-line execution loop.
    """

    # Create command-line parser.
    parser = argparse.ArgumentParser(
        description="Run a titere configuration.")

    # Define arguments.
    parser.add_argument('start_filename', type=str, nargs=1, help='Start file.')

    # Parse arguments.
    args = parser.parse_args()

    # Open Start file
    titere = Titere(filename=args.start_filename[0])

    # Apply configuration.
    try:
        titere.apply()
    except Exception, e:
        print colored(e, 'red')



import yaml
import fabric.api


class User(yaml.YAMLObject):

    yaml_tag = u'!User'

    def __init__(self, username, home=None, password=None, \
                 system=True, uid=None, gid=None):

        self.username = username
        self.home = home
        self.password = password
        self.uid = uid
        self.gid = gid
        self.system = system

    def apply(self):

        args = ' '

        # Home path
        if isinstance(self.home, basestring):
            args += '--home %s ' % (self.home, )

        # system user.
        if self.system:
            args += '--system '

        cmd = 'useradd%(args)s%(username)s' % {
            'args': args,
            'username': self.username}

        # Create user.
        fabric.api.local(cmd)



import yaml
from tags import User


class Titere(object):

    def __init__(self, filename):

        # Read filename
        print filename
        fd = open(filename)
        document = fd.read()
        fd.close()

        # Parse document.
        self.start = yaml.load(document)

    def apply(self):

        # Apply
        self.start.apply()



from setuptools import setup, find_packages

fd = open("README")
long_description = fd.read()
fd.close()

setup(
    name='titere',
    version='0.1',
    description='Automated toold that manage configurations',
    author='Jorge Eduardo Cardona',
    author_email='jorgeecardona@gmail.com',
    license="BSD",
    url="http://pypi.python.org/pypi/titere/",
    long_description=long_description,
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'titere = titere.main:main',
            ],
        },
    classifiers=[
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: BSD License",
        ],
    )
